@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -34,9 +35,7 @@
 #include <vcl/wrkwin.hxx>
 #include <sfx2/printer.hxx>
 #include <sfx2/app.hxx>
-#ifndef SD_OUTLINE_HXX
 #include "Outliner.hxx"
-#endif
 #include <editeng/paperinf.hxx>
 #include <svx/svdopage.hxx>
 #include <svx/svdoole2.hxx>
@@ -568,8 +567,7 @@ void SdDrawDocument::CreateFirstPages( SdDrawDocument* pRefDocument /* = 0 */ )
         /**********************************************************************
         * Handzettel-Seite einfuegen
         **********************************************************************/
-        BOOL bMasterPage;
-        SdPage* pHandoutPage = dynamic_cast< SdPage* >( AllocPage(bMasterPage=FALSE) );
+        SdPage* pHandoutPage = dynamic_cast< SdPage* >( AllocPage(FALSE) );
 
         SdPage* pRefPage = NULL;
 
@@ -594,7 +592,7 @@ void SdDrawDocument::CreateFirstPages( SdDrawDocument* pRefDocument /* = 0 */ )
         /**********************************************************************
         * MasterPage einfuegen und an der Handzettel-Seite vermerken
         **********************************************************************/
-        SdPage* pHandoutMPage = (SdPage*) AllocPage(bMasterPage=TRUE);
+        SdPage* pHandoutMPage = (SdPage*) AllocPage(TRUE);
         pHandoutMPage->SetSize( pHandoutPage->GetSize() );
         pHandoutMPage->SetPageKind(PK_HANDOUT);
         pHandoutMPage->SetBorder( pHandoutPage->GetLftBorder(),
@@ -617,7 +615,7 @@ void SdDrawDocument::CreateFirstPages( SdDrawDocument* pRefDocument /* = 0 */ )
 
         if (nPageCount == 0)
         {
-            pPage = dynamic_cast< SdPage* >( AllocPage(bMasterPage=FALSE) );
+            pPage = dynamic_cast< SdPage* >( AllocPage(FALSE) );
 
             if( pRefPage )
             {
@@ -673,7 +671,7 @@ void SdDrawDocument::CreateFirstPages( SdDrawDocument* pRefDocument /* = 0 */ )
         /**********************************************************************
         * MasterPage einfuegen und an der Seite vermerken
         **********************************************************************/
-        SdPage* pMPage = (SdPage*) AllocPage(bMasterPage=TRUE);
+        SdPage* pMPage = (SdPage*) AllocPage(TRUE);
         pMPage->SetSize( pPage->GetSize() );
         pMPage->SetBorder( pPage->GetLftBorder(),
                            pPage->GetUppBorder(),
@@ -687,7 +685,7 @@ void SdDrawDocument::CreateFirstPages( SdDrawDocument* pRefDocument /* = 0 */ )
         /**********************************************************************
         * Notizen-Seite einfuegen
         **********************************************************************/
-        SdPage* pNotesPage = (SdPage*) AllocPage(bMasterPage=FALSE);
+        SdPage* pNotesPage = (SdPage*) AllocPage(FALSE);
 
         if( pRefDocument )
             pRefPage = pRefDocument->GetSdPage( 0, PK_NOTES );
@@ -719,7 +717,7 @@ void SdDrawDocument::CreateFirstPages( SdDrawDocument* pRefDocument /* = 0 */ )
         /**********************************************************************
         * MasterPage einfuegen und an der Notizen-Seite vermerken
         **********************************************************************/
-        SdPage* pNotesMPage = (SdPage*) AllocPage(bMasterPage=TRUE);
+        SdPage* pNotesMPage = (SdPage*) AllocPage(TRUE);
         pNotesMPage->SetSize( pNotesPage->GetSize() );
         pNotesMPage->SetPageKind(PK_NOTES);
         pNotesMPage->SetBorder( pNotesPage->GetLftBorder(),
@@ -1622,3 +1620,5 @@ sd::UndoManager* SdDrawDocument::GetUndoManager() const
 }
 
 // eof
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
