@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -99,7 +100,7 @@ static xub_StrLen lcl_getMaxSafeStrLen(sal_uInt32 nSize)
     if (nSize > STRING_MAXLEN)
         nSize = STRING_MAXLEN;
 
-    return nSize;
+    return static_cast< xub_StrLen >( nSize );
 }
 
 BOOL PropItem::Read( String& rString, sal_uInt32 nStringType, sal_Bool bAlign )
@@ -731,3 +732,5 @@ PropRead& PropRead::operator=( PropRead& rPropRead )
     }
     return *this;
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
