@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -40,12 +41,8 @@
 #include <com/sun/star/drawing/XDrawPage.hpp>
 #include <svx/ShapeTypeHandler.hxx>
 #include "CustomAnimationList.hxx"
-#ifndef _SD_CUSTOMANIMATIONPANE_HRC
 #include "CustomAnimationPane.hrc"
-#endif
-#ifndef _SD_CUSTOMANIMATION_HRC
 #include "CustomAnimation.hrc"
-#endif
 #include "CustomAnimationPreset.hxx"
 #include <svtools/treelist.hxx>
 #include <vcl/svapp.hxx>
@@ -1016,3 +1013,5 @@ void CustomAnimationList::Paint( const Rectangle& rRect )
 }
 
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
