@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -30,9 +31,7 @@
 #include <svx/svdmodel.hxx>
 #include <sfx2/app.hxx>
 #include <sfx2/sfx.hrc>
-#ifndef _SV_SALBTYPE_HRC //autogen
 #include <vcl/salbtype.hxx>
-#endif
 #include <unotools/syslocale.hxx>
 
 #include "app.hxx"
@@ -1586,3 +1585,5 @@ void SdOptions::StoreConfig( ULONG nOptionsRange )
     if( nOptionsRange & SD_OPTIONS_PRINT )
         SdOptionsPrint::Store();
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
