@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -68,9 +69,7 @@
 #include "sdresid.hxx"
 #include "OutlineViewShell.hxx"
 #include "ViewShellBase.hxx"
-#ifndef SD_FRAMW_VIEW_HXX
 #include "FrameView.hxx"
-#endif
 #include "FactoryIds.hxx"
 #include "sdabstdlg.hxx"
 #include <memory>
@@ -1063,3 +1062,5 @@ void OutlineToImpressFinalizer::operator() (bool)
 
 
 } // end of anonymous namespace
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
