@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -55,9 +56,7 @@
 #include "res_bmp.hrc"
 #include "ViewShell.hxx"
 
-#ifndef _SV_SVAPP_HXX_ 
 #include <vcl/svapp.hxx>
-#endif
 
 #include <string>
 #include <algorithm>
@@ -1310,3 +1309,5 @@ void AnimationControllerItem::StateChanged( USHORT nSId,
 
 
 } // end of namespace sd
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
