@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -33,9 +34,7 @@
 #include <tools/urlobj.hxx>
 #include <sfx2/progress.hxx>
 #include <vcl/waitobj.hxx>
-#ifndef _SVXIDS_HRC
 #include <svx/svxids.hrc>
-#endif
 #include <editeng/flstitem.hxx>
 #include <editeng/eeitem.hxx>
 #include <svl/aeitem.hxx>
@@ -43,16 +42,12 @@
 #include <sot/storage.hxx>
 #include <sfx2/docfile.hxx>
 #include <sfx2/docfilt.hxx>
-#ifndef _DISPATCH_HXX //autogen
 #include <sfx2/dispatch.hxx>
-#endif
 #include <svx/svdotext.hxx>
 #include <svl/style.hxx>
 #include <sfx2/printer.hxx>
 #include <svtools/ctrltool.hxx>
-#ifndef _SFX_ECODE_HXX //autogen
 #include <svtools/sfxecode.hxx>
-#endif
 #include <sot/clsids.hxx>
 #include <sot/formats.hxx>
 #include <sfx2/request.hxx>
@@ -63,7 +58,6 @@
 #include <unotools/fltrcfg.hxx>
 #include <sfx2/frame.hxx>
 #include <sfx2/viewfrm.hxx>
-//#include <svx/svxmsbas.hxx>
 #include <unotools/saveopt.hxx>
 #include <com/sun/star/drawing/XDrawPage.hpp>
 #include <com/sun/star/drawing/XDrawView.hpp>
@@ -73,9 +67,7 @@
 #include "glob.hrc"
 #include "strings.hrc"
 #include "strmname.h"
-#ifndef SD_FRAMW_VIEW_HXX
 #include "FrameView.hxx"
-#endif
 #include "optsitem.hxx"
 #include "Outliner.hxx"
 #include "sdattr.hxx"
@@ -452,6 +444,37 @@ BOOL DrawDocShell::LoadFrom( SfxMedium& rMedium )
     return bRet;
 }
 
+/*************************************************************************
+|*
+|* ImportFrom: load from 3rd party format
+|*
+\************************************************************************/
+
+sal_Bool DrawDocShell::ImportFrom( SfxMedium &rMedium )
+{
+    const sal_Bool bRet=SfxObjectShell::ImportFrom(rMedium);
+
+    SfxItemSet* pSet = rMedium.GetItemSet();
+    if( pSet )
+    {
+        if( SFX_ITEM_SET == pSet->GetItemState(SID_DOC_STARTPRESENTATION)&&
+            ( (SfxBoolItem&) ( pSet->Get( SID_DOC_STARTPRESENTATION ) ) ).GetValue() )
+        {
+            mpDoc->SetStartWithPresentation( true );
+
+            // tell SFX to change viewshell when in preview mode
+            if( IsPreview() )
+            {
+                SfxItemSet *pMediumSet = GetMedium()->GetItemSet();
+                if( pMediumSet )
+                    pMediumSet->Put( SfxUInt16Item( SID_VIEW_ID, 1 ) );
+            }
+        }
+    }
+
+    return bRet;
+}
+
 /*************************************************************************
 |*
 |* ConvertFrom: aus Fremdformat laden
@@ -484,7 +507,9 @@ BOOL DrawDocShell::ConvertFrom( SfxMedium& rMedium )
         }
     }
 
-    if( aFilterName == pFilterPowerPoint97 || aFilterName == pFilterPowerPoint97Template)
+    if( aFilterName == pFilterPowerPoint97
+        || aFilterName == pFilterPowerPoint97Template
+        || aFilterName == pFilterPowerPoint97AutoPlay)
     {
         mpDoc->StopWorkStartupDelay();
         bRet = SdPPTFilter( rMedium, *this, sal_True ).Import();
@@ -1027,3 +1052,5 @@ void DrawDocShell::OpenBookmark( const String& rBookmarkURL )
 }
 
 } // end of namespace sd
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
