@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -1328,7 +1329,7 @@ public:
             ::boost::dynamic_pointer_cast<DrawViewShell>(mrBase.GetMainViewShell()));
 
         if ( ! mpPrintView)
-            mpPrintView.reset(new DrawView(mrBase.GetDocShell(), &rPrinter, pDrawViewShell.get()));
+            mpPrintView.reset(new DrawView(mrBase.GetDocShell(), &rPrinter, NULL));
 
         if (nIndex<0 || sal::static_int_cast<sal_uInt32>(nIndex)>=maPrinterPages.size())
             return;
@@ -2257,12 +2258,6 @@ private:
                                 
             // if CutPage is set then do not move it, otherwise move the
             // scaled page to printable area
-            #if 0
-            if (bCutPage)
-                aMap.SetOrigin(Point(-aPageOffset.X(), -aPageOffset.Y()));
-            else
-                aMap.SetOrigin(Point(0,0));
-            #endif
             maPrinterPages.push_back(
                 ::boost::shared_ptr<PrinterPage>(
                     new RegularPrinterPage(
@@ -2287,13 +2282,9 @@ private:
                 rInfo.maPageSize.Width() - rPage.GetLftBorder() - rPage.GetRgtBorder());
             const long nPageHeight (
                 rInfo.maPageSize.Height() - rPage.GetUppBorder() - rPage.GetLwrBorder());
-            #if 0
-            Point aOrigin (
-                nPageWidth < rInfo.maPrintSize.Width() ? -aPageOffset.X() : 0,
-                nPageHeight < rInfo.maPrintSize.Height() ? -aPageOffset.Y() : 0);
-            #else
+
             Point aOrigin ( 0, 0 );
-            #endif
+
             for (Point aPageOrigin = aOrigin;
                  -aPageOrigin.Y()<nPageHeight;
                  aPageOrigin.Y() -= rInfo.maPrintSize.Height())
@@ -2386,3 +2377,5 @@ void SAL_CALL DocumentRenderer::render (
 
 
 } // end of namespace sd
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
