@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -650,34 +651,30 @@ void ViewShellManager::Implementation::ActivateSubShell (
 {
     ::osl::MutexGuard aGuard (maMutex);
 
-    do
-    {
-        // Check that the given view shell is active.
-        ActiveShellList::iterator iShell (::std::find_if (
-            maActiveViewShells.begin(),
-            maActiveViewShells.end(),
-            IsShell(&rParentShell)));
-        if (iShell == maActiveViewShells.end())
-            break;
+    // Check that the given view shell is active.
+    ActiveShellList::iterator iShell (::std::find_if (
+        maActiveViewShells.begin(),
+        maActiveViewShells.end(),
+        IsShell(&rParentShell)));
+    if (iShell == maActiveViewShells.end())
+        return;
 
-        // Create the sub shell list if it does not yet exist.
-        SubShellList::iterator iList (maActiveSubShells.find(&rParentShell));
-        if (iList == maActiveSubShells.end())
-            iList = maActiveSubShells.insert(
-                SubShellList::value_type(&rParentShell,SubShellSubList())).first;
-        
-        // Do not activate an object bar that is already active.  Requesting
-        // this is not exactly an error but may be an indication of one.
-        SubShellSubList& rList (iList->second);
-        if (::std::find_if(rList.begin(),rList.end(), IsId(nId)) != rList.end())
-            break;
+    // Create the sub shell list if it does not yet exist.
+    SubShellList::iterator iList (maActiveSubShells.find(&rParentShell));
+    if (iList == maActiveSubShells.end())
+        iList = maActiveSubShells.insert(
+            SubShellList::value_type(&rParentShell,SubShellSubList())).first;
 
-        // Add just the id of the sub shell. The actual shell is created
-        // later in CreateShells().
-        UpdateLock aLock (*this);
-        rList.push_back(ShellDescriptor(NULL, nId));
-    }
-    while (false);
+    // Do not activate an object bar that is already active.  Requesting
+    // this is not exactly an error but may be an indication of one.
+    SubShellSubList& rList (iList->second);
+    if (::std::find_if(rList.begin(),rList.end(), IsId(nId)) != rList.end())
+        return;
+
+    // Add just the id of the sub shell. The actual shell is created
+    // later in CreateShells().
+    UpdateLock aLock (*this);
+    rList.push_back(ShellDescriptor(NULL, nId));
 }
 
 
@@ -689,34 +686,30 @@ void ViewShellManager::Implementation::DeactivateSubShell (
 {
     ::osl::MutexGuard aGuard (maMutex);
 
-    do
-    {
-        // Check that the given view shell is active.
-        SubShellList::iterator iList (maActiveSubShells.find(&rParentShell));
-        if (iList == maActiveSubShells.end())
-            break;
+    // Check that the given view shell is active.
+    SubShellList::iterator iList (maActiveSubShells.find(&rParentShell));
+    if (iList == maActiveSubShells.end())
+        return;
 
-        // Look up the sub shell.
-        SubShellSubList& rList (iList->second);
-        SubShellSubList::iterator iShell (
-            ::std::find_if(rList.begin(),rList.end(), IsId(nId)));
-        if (iShell == rList.end())
-            break;
-        SfxShell* pShell = iShell->mpShell;
-        if (pShell == NULL)
-            break;
-        
-        UpdateLock aLock (*this);
+    // Look up the sub shell.
+    SubShellSubList& rList (iList->second);
+    SubShellSubList::iterator iShell (
+        ::std::find_if(rList.begin(),rList.end(), IsId(nId)));
+    if (iShell == rList.end())
+        return;
+    SfxShell* pShell = iShell->mpShell;
+    if (pShell == NULL)
+        return;
 
-        ShellDescriptor aDescriptor(*iShell);
-        // Remove the sub shell from both the internal structure as well as the
-        // SFX shell stack above and including the sub shell.
-        rList.erase(iShell);
-        TakeShellsFromStack(pShell);
+    UpdateLock aLock (*this);
 
-        DestroySubShell(rParentShell, aDescriptor);
-    }
-    while (false);
+    ShellDescriptor aDescriptor(*iShell);
+    // Remove the sub shell from both the internal structure as well as the
+    // SFX shell stack above and including the sub shell.
+    rList.erase(iShell);
+    TakeShellsFromStack(pShell);
+
+    DestroySubShell(rParentShell, aDescriptor);
 }
 
 
@@ -1462,3 +1455,5 @@ bool ShellDescriptor::IsMainViewShell (void) const
 } // end of anonymous namespace
 
 } // end of namespace sd
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
