@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -32,17 +33,11 @@
 #include "ViewShellImplementation.hxx"
 #include <vcl/waitobj.hxx>
 #include <svx/svdograf.hxx>
-#ifndef _SVXIDS_HRC
 #include <svx/svxids.hrc>
-#endif
 #include <svx/svdpagv.hxx>
 #include <svx/svdundo.hxx>
-#ifndef _ZOOMITEM_HXX
 #include <svx/zoomitem.hxx>
-#endif
-#ifndef _EDITDATA_HXX
 #include <editeng/editdata.hxx>
-#endif
 #include <basic/sberrors.hxx>
 #include <vcl/msgbox.hxx>
 #include <sfx2/request.hxx>
@@ -56,9 +51,7 @@
 #include <svx/xlineit0.hxx>
 #include <svx/xfillit0.hxx>
 
-#ifndef _SDOUTL_HXX //autogen
 #include <svx/svdoutl.hxx>
-#endif
 #include <svx/xlnwtit.hxx>
 #include <svx/svdoattr.hxx>
 #include <svx/xlnstwit.hxx>
@@ -998,3 +991,5 @@ SdPage* DrawViewShell::CreateOrDuplicatePage (
 }
 
 } // end of namespace sd
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
