@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -285,7 +286,9 @@ ShapeSharedPtr ShapeImporter::createShape(
     rtl::OUString const& shapeType ) const
 {
     if( shapeType.equalsAsciiL( 
-            RTL_CONSTASCII_STRINGPARAM("com.sun.star.drawing.MediaShape") )) 
+            RTL_CONSTASCII_STRINGPARAM("com.sun.star.drawing.MediaShape") ) || 
+        shapeType.equalsAsciiL( 
+            RTL_CONSTASCII_STRINGPARAM("com.sun.star.presentation.MediaShape") ) ) 
     {
         // Media shape (video etc.). This is a special object
         return createMediaShape(xCurrShape, 
@@ -337,7 +340,9 @@ ShapeSharedPtr ShapeImporter::createShape(
                                   mrContext );
     }
     else if( shapeType.equalsAsciiL(
-                 RTL_CONSTASCII_STRINGPARAM("com.sun.star.drawing.OLE2Shape") ))
+                 RTL_CONSTASCII_STRINGPARAM("com.sun.star.drawing.OLE2Shape") ) ||
+             shapeType.equalsAsciiL(
+                RTL_CONSTASCII_STRINGPARAM("com.sun.star.presentation.OLE2Shape") ) )
     {
         // #i46224# Mark OLE shapes as foreign content - scan them for
         // unsupported actions, and fallback to bitmap, if necessary
@@ -349,7 +354,10 @@ ShapeSharedPtr ShapeImporter::createShape(
     }
     else if( shapeType.equalsAsciiL(
                  RTL_CONSTASCII_STRINGPARAM(
-                     "com.sun.star.drawing.GraphicObjectShape") )) 
+                     "com.sun.star.drawing.GraphicObjectShape") ) ||
+             shapeType.equalsAsciiL(
+                 RTL_CONSTASCII_STRINGPARAM(
+                     "com.sun.star.presentation.GraphicObjectShape") ) ) 
     {
         GraphicObject aGraphicObject;
         
@@ -513,12 +521,11 @@ void ShapeImporter::importPolygons(uno::Reference<beans::XPropertySet> const& xP
     
     ::basegfx::B2DPolygon aPoly;
     basegfx::B2DPoint aPoint;
-    for( sal_Int32 nCurrPoly=0; nCurrPoly<pOuterSequence->getLength(); ++nCurrPoly )
+    for( sal_Int32 nCurrPoly=0; nCurrPoly<pOuterSequence->getLength(); ++nCurrPoly, ++pInnerSequence )
     {
         aPoint.setX((*pInnerSequence).X);
         aPoint.setY((*pInnerSequence).Y);
         aPoly.append( aPoint );
-        *pInnerSequence++;
     }
     UnoViewVector::const_iterator aIter=(mrContext.mrViewContainer).begin();
     UnoViewVector::const_iterator aEnd=(mrContext.mrViewContainer).end();
@@ -669,3 +676,4 @@ ShapeImporter::ShapeImporter( uno::Reference<drawing::XDrawPage> const&
 } // namespace internal
 } // namespace presentation
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
